@@ -182,20 +182,23 @@ def add_parameter(key, key_option, value, value_option, stage, input, format, ve
 
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
     finally:
         if parameters:
-            if len(failed):
-                failure = [{'Key': x for x in failed}]
-            else:
-                failure = []
+            failure = []
+            for key in failed:
+                failure.append({'Key': key})
             result = {'Success': success, 'Failure': failure}
             output = format_data(result, '', 'json') ### FIXME: use a global output format setting
-            if output: Pager.page(output)
+            Pager.page(output)
+
 
 
 
@@ -233,16 +236,19 @@ def list_parameter(stage, uninherited, filter, query_all, query, format, verbosi
                         config_override)
         result = Parameters.list(stage, uninherited, filter)
         output = format_data(result, query, format)
-        if output: Pager.page(output)
+        # if output: Pager.page(output)
+        Pager.page(output)
 
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @parameter.command('get', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['parameter']['get']}")
@@ -277,15 +283,19 @@ def get_parameter(key, key_option, stage, revision, query_all, query, format, ve
                         config_override)
         result = Parameters.get(stage, key, revision)
         output = format_data(result, query, format)
-        if output: Pager.page(output)
+        # if output: Pager.page(output)
+        Pager.page(output)
+
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @parameter.command('history', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['parameter']['history']}")
@@ -319,15 +329,19 @@ def history_parameter(key, key_option, stage, query_all, query, format, verbosit
                         config_override)
         result = Parameters.history(stage, key)
         output = format_data(result, query, format)
-        if output: Pager.page(output)
+        # if output: Pager.page(output)
+        Pager.page(output)
+
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @parameter.command('delete', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['parameter']['delete']}")
@@ -376,21 +390,22 @@ def delete_parameter(key, key_option, input, format, stage, verbosity, global_sc
 
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
     finally:
         if parameters:
-            if len(failed):
-                failure = [{'Key': x for x in failed}]
-            else:
-                failure = []
+            failure = []
+            for key in failed:
+                failure.append({'Key': key})
             result = {'Success': success, 'Failure': failure}
             output = format_data(result, '', 'json') ### FIXME: use a global output format setting
-            if output: Pager.page(output)
-
+            Pager.page(output)
 
 
 
@@ -454,20 +469,23 @@ def add_secret(key, key_option, stage, input, format, verbosity, global_scope, p
 
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
     finally:
         if secrets:
-            if len(failed):
-                failure = [{'Key': x for x in failed}]
-            else:
-                failure = []
+            failure = []
+            for key in failed:
+                failure.append({'Key': key})
             result = {'Success': success, 'Failure': failure}
             output = format_data(result, '', 'json') ### FIXME: use a global output format setting
-            if output: Pager.page(output)
+            Pager.page(output)
+
 
 
 
@@ -506,16 +524,19 @@ def list_secret(stage, uninherited, decrypt, filter, query_all, query, format, v
                         config_override)
         result = Secrets.list(stage, uninherited, decrypt, filter)
         output = format_data(result, query, format)
-        if output: Pager.page(output)
+        # if output: Pager.page(output)
+        Pager.page(output)
 
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @secret.command('get', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['secret']['get']}")
@@ -553,16 +574,19 @@ def get_secret(key, key_option, stage, revision, decrypt, query_all, query, form
 
         result = Secrets.get(stage, key, revision, decrypt)
         output = format_data(result, query, format)
-        if output: Pager.page(output)
+        # if output: Pager.page(output)
+        Pager.page(output)
 
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @secret.command('history', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['secret']['history']}")
@@ -599,16 +623,19 @@ def history_secret(key, key_option, stage, decrypt, query_all, query, format, ve
 
         result = Secrets.history(stage, key, decrypt)
         output = format_data(result, query, format)
-        if output: Pager.page(output)
+        # if output: Pager.page(output)
+        Pager.page(output)
 
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @secret.command('delete', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['secret']['delete']}")
@@ -657,21 +684,22 @@ def delete_secret(key, key_option, input, format, stage, verbosity, global_scope
 
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
     finally:
         if secrets:
-            if len(failed):
-                failure = [{'Key': x for x in failed}]
-            else:
-                failure = []
+            failure = []
+            for key in failed:
+                failure.append({'Key': key})
             result = {'Success': success, 'Failure': failure}
             output = format_data(result, '', 'json') ### FIXME: use a global output format setting
-            if output: Pager.page(output)
-
+            Pager.page(output)
 
 
 
@@ -714,15 +742,19 @@ def list_template(uninherited, stage, include_contents, filter, query_all, query
                         config_override)
         result = Templates.list(stage, uninherited, include_contents, filter)
         output = format_data(result, query, format)
-        if output: Pager.page(output)
+        # if output: Pager.page(output)
+        Pager.page(output)
+
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @template.command('add', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['template']['add']}")
@@ -840,20 +872,23 @@ def add_template(key, key_option, render_path, input, recursive, stage, verbosit
 
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
     finally:
         if templates:
-            if len(failed):
-                failure = [{'Key': x for x in failed}]
-            else:
-                failure = []
+            failure = []
+            for key in failed:
+                failure.append({'Key': key})
             result = {'Success': success, 'Failure': failure}
             output = format_data(result, '', 'json') ### FIXME: use a global output format setting
-            if output: Pager.page(output)
+            Pager.page(output)
+
 
 
 
@@ -891,15 +926,19 @@ def get_template(key, key_option, stage, revision, include_contents, query_all,
 
         result = Templates.get(stage, key, revision)
         output = format_data(result, query, format)
-        if output: Pager.page(output)
+        # if output: Pager.page(output)
+        Pager.page(output)
+
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @template.command('history', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['template']['history']}")
@@ -938,15 +977,19 @@ def history_template(key, key_option, stage, include_contents, query_all, query,
 
         result = Templates.history(stage, key, include_contents)
         output = format_data(result, query, format)
-        if output: Pager.page(output)
+        # if output: Pager.page(output)
+        Pager.page(output)
+
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @template.command('delete', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['template']['delete']}")
@@ -993,20 +1036,23 @@ def delete_template(key, key_option, stage, input, format, verbosity, global_sco
             failed.remove(template['Key'])
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
     finally:
         if templates:
-            if len(failed):
-                failure = [{'Key': x for x in failed}]
-            else:
-                failure = []
+            failure = []
+            for key in failed:
+                failure.append({'Key': key})
             result = {'Success': success, 'Failure': failure}
             output = format_data(result, '', 'json') ### FIXME: use a global output format setting
-            if output: Pager.page(output)
+            Pager.page(output)
+
 
 
 
@@ -1039,16 +1085,19 @@ def render_template(stage, filter, verbosity, global_scope, project_scope, confi
         success = Templates.render(stage, filter)
         result = {'Success': success, 'Failure': []}
         output = format_data(result, '', 'json') ### FIXME: use a global output format setting
-        if output: Pager.page(output)
-    
+        # if output: Pager.page(output)
+        Pager.page(output)
+
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 
@@ -1082,12 +1131,14 @@ def list_package(stage, format, verbosity, global_scope, project_scope, config_o
     
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @package.command('download', context_settings=DEFAULT_CLICK_CONTEXT, short_help="Download a package")
@@ -1120,12 +1171,14 @@ def download_package(stage, package, format, verbosity, global_scope, project_sc
     
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @package.command('create', context_settings=DEFAULT_CLICK_CONTEXT, short_help="Create a package")
@@ -1158,12 +1211,14 @@ def create_package(stage, description, format, verbosity, global_scope, project_
     
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @package.command('delete', context_settings=DEFAULT_CLICK_CONTEXT, short_help="Delete a package")
@@ -1196,12 +1251,14 @@ def delete_package(stage, package, format, verbosity, global_scope, project_scop
     
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @release.command('list', context_settings=DEFAULT_CLICK_CONTEXT, short_help="List available releases")
@@ -1232,12 +1289,14 @@ def list_release(stage, format, verbosity, global_scope, project_scope, config_o
     
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @release.command('download', context_settings=DEFAULT_CLICK_CONTEXT, short_help="Download a release")
@@ -1270,12 +1329,14 @@ def download_release(stage, release, format, verbosity, global_scope, project_sc
     
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @release.command('create', context_settings=DEFAULT_CLICK_CONTEXT, short_help="Create a release")
@@ -1309,12 +1370,14 @@ def create_release(stage, description, format, verbosity, global_scope, project_
     
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 
@@ -1348,12 +1411,14 @@ def delete_release(stage, release, format, verbosity, global_scope, project_scop
     
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @release.command('deploy', context_settings=DEFAULT_CLICK_CONTEXT, short_help="Deploy a release")
@@ -1386,12 +1451,14 @@ def deploy_release(stage, release, format, verbosity, global_scope, project_scop
     
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @config.command('get', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['config']['get']}")
@@ -1428,12 +1495,14 @@ def get_config(key, key_option, local, global_, verbosity, global_scope, project
 
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @config.command('set', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['config']['set']}")
@@ -1477,12 +1546,14 @@ def set_config(key, key_option, value, value_option, global_, input, verbosity,
 
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 @config.command('delete', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['config']['delete']}")
@@ -1512,12 +1583,14 @@ def delete_config(key, key_option, global_, verbosity, global_scope, project_sco
 
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 # @config.command('setup', context_settings=DEFAULT_CLICK_CONTEXT, short_help=f"{CLI_COMMANDS_SHORT_HELP['config']['setup']}")
@@ -1546,6 +1619,7 @@ def delete_config(key, key_option, global_, verbosity, global_scope, project_sco
 #         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
 #         Logger.critical(msg)
 #         if verbosity >= log_levels['full']:
+            # import traceback
 #             raise
 
 
@@ -1585,12 +1659,14 @@ def init_config(setup, local, input, verbosity, global_scope, project_scope, con
 
     except DSOException as e:
         Logger.error(e.message)
+        sys.exit(1)
     except Exception as e:
         msg = getattr(e, 'message', getattr(e, 'msg', str(e)))
         Logger.critical(msg)
         if verbosity >= log_levels['full']:
-            raise
-
+            import traceback
+            traceback.print_exc()
+        sys.exit(2)
 
 
 modify_click_usage_error()
