@@ -169,10 +169,10 @@ class ConfigManager:
         _config = {}
         if context == 'global':
             _config['project'] = 'default'
-            Logger.warn("Switched from the application context to the global context.")
+            Logger.warn("Switched to the global context.")
         elif context == 'project':
             _config['application'] = 'default'
-            Logger.warn(f"Switched from the application context to the project context '{self.project}'.")
+            Logger.warn(f"Switched to the project context '{self.project}'.")
         elif context == 'application':
             pass
         return merge_dicts(self.config_string_to_dict(config_overrides_string), _config)
@@ -242,7 +242,7 @@ class ConfigManager:
             result  = os.getenv('DSO_APPLICATION') or 'default'
         if self.project == 'default':
             if not result == 'default':
-                # Logger.warn(f"Switched to project context '{self.project}' from the application context '{result}'.")
+                # Logger.warn(f"Switched to project context '{self.project}' '{result}'.")
                 Logger.debug(f"The application context '{result}' was reset because the global context is being used.")
                 result = 'default'
         return result.lower()
