@@ -1,13 +1,6 @@
-
-APPLICATION_NAME = "DSO Tool"
-REGEX_PATTERNS = {
-    'stage' : r"^([a-zA-Z][a-zA-Z0-9]+)/?([0-9])?$",
-    'parameter_key': r"^[a-zA-Z][.a-zA-Z0-9_-]*[a-zA-Z0-9]$",
-    'secret_key': r"^[a-zA-Z][.a-zA-Z0-9_-]*[a-zA-ZA-Z0-9]$",
-    'template_key': r"^[a-zA-Z][./a-zA-Z0-9_-]*[a-zA-Z0-9]$",
-}
-
 MESSAGES = {
+    'KeyNull': "Key must have a value.",
+    'DSOReserverdKey': "Key '{0}' is reserved and cannot be used.",
     'InvalidKeyPattern': "'{0}' is an invalid key. Must conform to '{1}'.",
     'InvalidKeyStr': "'{0}' is an invalid key. Cannot contain '{1}'.",
     'ParameterNotFound': "Parameter '{0}' not found in the given context.",
