@@ -1,12 +1,12 @@
-import os
 import logging
+from .settings import *
 # import re
 # from time import gmtime, strftime
 
-COLORIZE_LOGS = os.getenv('DSO_COLORIZE_LOGS') or True
-BOLD_LOGS = os.getenv('DSO_BOLD_LOGS') or True
-TIMESTAMP_LOGS = os.getenv('DSO_TIMESTAMP_LOGS') or True
-LABEL_LOG_LEVELS = os.getenv('DSO_LABEL_LOG_LEVELS') or True
+# COLORIZE_LOGS = os.getenv('DSO_COLORIZE_LOGS') or True
+# BOLD_LOGS = os.getenv('DSO_BOLD_LOGS') or True
+# TIMESTAMP_LOGS = os.getenv('DSO_TIMESTAMP_LOGS') or True
+# LABEL_LOG_LEVELS = os.getenv('DSO_LABEL_LOG_LEVELS') or True
 
 COLOR_CODES = {
     'black': u'0;30', 
@@ -97,8 +97,8 @@ color_codes = {
     },
 }
 
-# ###--------------------------------------------------------------------------------------------
-# ###--------------------------------------------------------------------------------------------
+# 
+# 
 
 # def decode_color_codes(s):
 #     r = re.findall("{0}(.*?){1}(.*?){2}".format(re.escape('<?'), re.escape('>'), re.escape('</?>')), s)
@@ -108,8 +108,8 @@ color_codes = {
 #     return s
 
 
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
+
+
 
 
 def format_text(msg, color):
@@ -120,8 +120,8 @@ def format_text(msg, color):
     else:
         return '{0}{1}{2}'.format(color_codes['uncolored'][style], msg, style_codes['reset'])
 
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
+
+
 
 
 class LoggerClass():
@@ -137,7 +137,7 @@ class LoggerClass():
         if LABEL_LOG_LEVELS: log_format += ' [%(levelname)-8s]'
         log_format += ' %(message)s'
         logging.basicConfig(format=log_format, datefmt='%Y-%m-%d %H:%M:%S', level=logger_verbosity_map[str(log_level)])
-        self.LOG = logging.getLogger('mabledsocli')
+        self.LOG = logging.getLogger('dsocli')
 
     def set_verbosity(self, log_level):
         self.__level = log_level
@@ -179,7 +179,7 @@ class LoggerClass():
             finally:
                 self.LOG.root.level=saveLevel
 
-    ###--------------------------------------------------------------------------------------------
+    
 
     ### log debug message if (requested) log_level is greater than LOG_LEVEL_debug
     def debug(self, msg, force=False):
@@ -191,7 +191,7 @@ class LoggerClass():
             finally:
                 self.LOG.root.level=saveLevel
 
-    ###--------------------------------------------------------------------------------------------
+    
 
     # ### always log
     # def force(self, msg, stress=True):
@@ -203,8 +203,8 @@ class LoggerClass():
     #         self.LOG.root.level=saveLevel
 
 
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
+
+
 
 # boto3.set_stream_logger('boto3.resources', logging.ERROR)
 
