@@ -19,27 +19,22 @@ _default_spec = {
 def get_default_spec():
     return _default_spec.copy()
 
+
 _settings = {
     'id': 'parameter/aws/ssm/v1',
 }
 
-session = boto3.session.Session()
-ssm = session.client(
-    service_name='ssm',
-)
-
 
 class AwsSsmParameterProvider(ParameterProvider):
 
     def __init__(self):
         super().__init__(_settings['id'])
 
-###--------------------------------------------------------------------------------------------
 
     def get_prefix(self):
         return Configs.parameter_spec('prefix')
 
-###--------------------------------------------------------------------------------------------
+
 
     def list(self, project, application, stage, uninherited=False, filter=None):
         parameters = load_context_ssm_parameters(project, application, stage, 'String', prefix=self.get_prefix(), uninherited=uninherited)
@@ -58,7 +53,7 @@ class AwsSsmParameterProvider(ParameterProvider):
 
         return result
 
-###--------------------------------------------------------------------------------------------
+
 
     def add(self, project, application, stage, key, value):
         Logger.debug(f"Checking SSM parameter overwrites: project={project}, application={application}, stage={stage}, key={key}")
@@ -69,7 +64,7 @@ class AwsSsmParameterProvider(ParameterProvider):
             raise DSOException(f"Failed to add parameter '{key}' becasue becasue the key is not available in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         path = get_ssm_path(project, application, stage=stage, key=key, prefix=self.get_prefix())
         Logger.info(f"Adding SSM parameter: path={path}")
-        response = ssm.put_parameter(Name=path, Value=value, Type='String', Overwrite=True)
+        response = put_ssm_paramater(path, value)
         return {
                 'Key': key, 
                 'Value': value,
@@ -83,7 +78,7 @@ class AwsSsmParameterProvider(ParameterProvider):
                 # 'Path': path,
                 }
 
-###--------------------------------------------------------------------------------------------
+
 
     def get(self, project, application, stage, key, revision=None):
         Logger.debug(f"Locating SSM parameter: project={project}, application={application}, stage={stage}, key={key}")
@@ -94,7 +89,7 @@ class AwsSsmParameterProvider(ParameterProvider):
             if not found['Type'] == 'String':
                 raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM parameter: path={found['Name']}")
-        response = ssm.get_parameter_history(Name=found['Name'])
+        response = get_ssm_parameter_history(found['Name'])
         parameters = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
         if revision is None:
             ### get the latest revision
@@ -102,6 +97,7 @@ class AwsSsmParameterProvider(ParameterProvider):
                     'RevisionId': str(parameters[0]['Version']),
                     'Date': parameters[0]['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                     'Key': key, 
+                    # 'Value': decode_nulls(parameters[0]['Value']),
                     'Value': parameters[0]['Value'],
                     'Scope': found['Scope'],
                     'Origin': found['Origin'],
@@ -117,7 +113,7 @@ class AwsSsmParameterProvider(ParameterProvider):
                     'RevisionId':str(parameters[0]['Version']),
                     'Date': parameters[0]['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                     'Key': key, 
-                    'Value': parameters[0]['Value'],
+                    'Value': decode_nulls(parameters[0]['Value']),
                     'Scope': found['Scope'],
                     'Origin': found['Origin'],
                     'Path': found['Name'],
@@ -126,7 +122,7 @@ class AwsSsmParameterProvider(ParameterProvider):
 
         return result
 
-###--------------------------------------------------------------------------------------------
+
 
     def history(self, project, application, stage, key):
         Logger.debug(f"Locating SSM parameter: project={project}, application={application}, stage={stage}, key={key}")
@@ -137,14 +133,14 @@ class AwsSsmParameterProvider(ParameterProvider):
             if not found['Type'] == 'String':
                 raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM parameter: path={found['Name']}")
-        response = ssm.get_parameter_history(Name=found['Name'])
+        response = get_ssm_parameter_history(found['Name'])
         parameters = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
         result = { "Revisions":
             [{
                 'RevisionId': str(parameter['Version']),
                 'Date': parameter['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                 # 'Key': key,
-                'Value': parameter['Value'],
+                'Value': decode_nulls(parameter['Value']),
                 # 'Scope': found['Scope'],
                 # 'Origin': found['Origin'],
                 'User': parameter['LastModifiedUser'],
@@ -154,7 +150,7 @@ class AwsSsmParameterProvider(ParameterProvider):
 
         return result
 
-###--------------------------------------------------------------------------------------------
+
 
     def delete(self, project, application, stage, key):
         Logger.debug(f"Locating SSM parameter: project={project}, application={application}, stage={stage}, key={key}")
@@ -168,7 +164,7 @@ class AwsSsmParameterProvider(ParameterProvider):
             if not found['Type'] == 'String':
                 raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Deleting SSM parameter: path={found['Name']}")
-        ssm.delete_parameter(Name=found['Name'])
+        delete_ssm_parameter(found['Name'])
         return {
                 'Key': key, 
                 'Scope': found['Scope'],
@@ -176,8 +172,7 @@ class AwsSsmParameterProvider(ParameterProvider):
                 # 'Path': found['Name'],
                 }
 
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
 
-Providers.register(AwsSsmParameterProvider())
+
+def register():
+    Providers.register(AwsSsmParameterProvider())
