@@ -19,28 +19,24 @@ _default_spec = {
 def get_default_spec():
     return _default_spec.copy()
 
+
 _settings = {
     'id': 'secret/aws/ssm/v1',
 }
 
 
-session = boto3.session.Session()
-ssm = session.client(
-    service_name='ssm',
-)
-
 
 class AwsSsmSecretProvider(SecretProvider):
 
+
     def __init__(self):
         super().__init__(_settings['id'])
 
-###--------------------------------------------------------------------------------------------
 
     def get_prefix(self):
         return Configs.secret_spec('prefix')
 
-###--------------------------------------------------------------------------------------------
+
 
     def list(self, project, application, stage, uninherited=False, decrypt=False, filter=None):
         secrets = load_context_ssm_parameters(project, application, stage, 'SecureString', prefix=self.get_prefix(), uninherited=uninherited, decrypt=decrypt)
@@ -59,7 +55,7 @@ class AwsSsmSecretProvider(SecretProvider):
 
         return result
 
-###--------------------------------------------------------------------------------------------
+
 
     def add(self, project, application, stage, key, value):
         Logger.debug(f"Checking SSM secret overwrites: project={project}, application={application}, stage={stage}, key={key}")
@@ -70,7 +66,7 @@ class AwsSsmSecretProvider(SecretProvider):
             raise DSOException(f"Failed to add secret '{key}' becasue becasue the key is not available in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         path = get_ssm_path(project, application, stage=stage, key=key, prefix=self.get_prefix())
         Logger.info(f"Adding SSM secret: path={path}")
-        response = ssm.put_parameter(Name=path, Value=value, Type='SecureString', Overwrite=True)
+        response = put_ssm_secret(path, value)
         return {
                 'Key': key, 
                 'Value': value,
@@ -84,7 +80,7 @@ class AwsSsmSecretProvider(SecretProvider):
                 # 'Path': path,
                 }
 
-###--------------------------------------------------------------------------------------------
+
 
     def get(self, project, application, stage, key, revision=None, decrypt=False):
         Logger.debug(f"Locating SSM secret: project={project}, application={application}, stage={stage}, key={key}")
@@ -95,7 +91,7 @@ class AwsSsmSecretProvider(SecretProvider):
             if not found['Type'] == 'SecureString':
                 raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM secret: path={found['Name']}")
-        response = ssm.get_parameter_history(Name=found['Name'], WithDecryption=decrypt)
+        response = get_ssm_secret_history(found['Name'], decrypt)
         secrets = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
         if revision is None:
             ### get the latest revision
@@ -103,7 +99,7 @@ class AwsSsmSecretProvider(SecretProvider):
                     'RevisionId': str(secrets[0]['Version']),
                     'Date': secrets[0]['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                     'Key': key, 
-                    'Value': secrets[0]['Value'],
+                    'Value': decode_nulls(secrets[0]['Value']),
                     'Scope': found['Scope'],
                     'Origin': found['Origin'],
                     'Path': found['Name'],
@@ -118,7 +114,7 @@ class AwsSsmSecretProvider(SecretProvider):
                     'RevisionId': str(secrets[0]['Version']),
                     'Date': secrets[0]['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                     'Key': key, 
-                    'Value': secrets[0]['Value'],
+                    'Value': decode_nulls(secrets[0]['Value']),
                     'Scope': found['Scope'],
                     'Origin': found['Origin'],
                     'Path': found['Name'],
@@ -127,7 +123,7 @@ class AwsSsmSecretProvider(SecretProvider):
 
         return result
 
-###--------------------------------------------------------------------------------------------
+
 
     def history(self, project, application, stage, key, decrypt=False):
         found = locate_ssm_parameter_in_context_hierachy(project, application, stage, key, prefix=self.get_prefix())
@@ -137,14 +133,14 @@ class AwsSsmSecretProvider(SecretProvider):
             if not found['Type'] == 'SecureString':
                 raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM secret: path={found['Name']}")
-        response = ssm.get_parameter_history(Name=found['Name'], WithDecryption=decrypt)
+        response = get_ssm_secret_history(found['Name'], decrypt)
         secrets = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
         result = { "Revisions":
             [{
                 'RevisionId': str(secret['Version']),
                 'Date': secret['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                 # 'Key': key,
-                'Value': secret['Value'],
+                'Value': decode_nulls(secret['Value']),
                 # 'Scope': found['Scope'],
                 # 'Origin': found['Origin'],
                 'User': secret['LastModifiedUser'],
@@ -154,7 +150,7 @@ class AwsSsmSecretProvider(SecretProvider):
 
         return result
 
-###--------------------------------------------------------------------------------------------
+
 
     def delete(self, project, application, stage, key):
         Logger.debug(f"Locating SSM secret: project={project}, application={application}, stage={stage}, key={key}")
@@ -168,7 +164,7 @@ class AwsSsmSecretProvider(SecretProvider):
             if not found['Type'] == 'SecureString':
                 raise DSOException(f"Secret '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Deleting SSM secret: path={found['Name']}")
-        ssm.delete_parameter(Name=found['Name'])
+        delete_ssm_parameter(found['Name'])
         return {
                 'Key': key, 
                 'Scope': found['Scope'],
@@ -176,8 +172,7 @@ class AwsSsmSecretProvider(SecretProvider):
                 # 'Path': found['Name'],
                 }
 
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
 
-Providers.register(AwsSsmSecretProvider())
+
+def register():
+    Providers.register(AwsSsmSecretProvider())
