@@ -19,20 +19,19 @@ _default_spec = {
 def get_default_spec():
     return _default_spec.copy()
 
+
 _settings = {
     'id': 'template/aws/ssm/v1',
 }
 
-session = boto3.session.Session()
-ssm = session.client(
-    service_name='ssm',
-)
-
 
 class AwsSsmTemplateProvider(TemplateProvider):
 
+    ssm = None
+
     def __init__(self):
         super().__init__(_settings['id'])
+        self.ssm = boto3.session.Session().client(service_name='ssm')
 
 
 
@@ -74,7 +73,7 @@ class AwsSsmTemplateProvider(TemplateProvider):
         if len(contents) > 4096:
             raise DSOException(f"This template provider does not support templates larger than 4KB.")
         if not Stages.is_default(stage) and not ALLOW_STAGE_TEMPLATES:
-            raise DSOException(f"Templates may not be added to stage scopes, as the feature is currently disabled. It may be enabled using 'ALLOW_STAGE_TEMPLATES' in the DSO global settings.")
+            raise DSOException(f"Templates may not be added to stage scopes, as the feature is currently disabled. It may be enabled by setting 'ALLOW_STAGE_TEMPLATES' to 'yes' in the DSO global settings.")
         Logger.debug(f"Checking SSM template overwrites: project={project}, application={application}, stage={stage}, key={key}")
         assert_ssm_parameter_no_namespace_overwrites(project, application, stage, key, prefix=self.get_prefix())
         Logger.debug(f"Locating SSM template: project={project}, application={application}, stage={stage}, key={key}")
@@ -83,7 +82,7 @@ class AwsSsmTemplateProvider(TemplateProvider):
             raise DSOException(f"Failed to add template '{key}' becasue becasue the key is not available in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         path = get_ssm_path(project, application, stage=stage, key=key, prefix=self.get_prefix())
         Logger.info(f"Adding SSM template: path={path}")
-        response = ssm.put_parameter(Name=path, Value=escape_curly_brackets(contents), Type='StringList', Overwrite=True)
+        response = put_ssm_template(path, contents)
         return {
                 'Key': key,
                 'Scope': Contexts.translate_context(project, application, stage),
@@ -107,7 +106,7 @@ class AwsSsmTemplateProvider(TemplateProvider):
             if not found['Type'] == 'StringList':
                 raise DSOException(f"Template '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM template: path={found['Name']}")
-        response = ssm.get_parameter_history(Name=found['Name'])
+        response = get_ssm_template_history(found['Name'])
         templates = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
         if revision is None:
             ### get the latest revision
@@ -119,7 +118,8 @@ class AwsSsmTemplateProvider(TemplateProvider):
                     'Origin': found['Origin'],
                     'User': templates[0]['LastModifiedUser'],
                     'Path': found['Name'],
-                    'Contents': unescape_curly_brackets(templates[0]['Value']),
+                    # 'Contents': unescape_curly_brackets(templates[0]['Value']),
+                    'Contents': templates[0]['Value'],
                     }
         else:
             ### get specific revision
@@ -134,7 +134,8 @@ class AwsSsmTemplateProvider(TemplateProvider):
                     'Origin': found['Origin'],
                     'User': templates[0]['LastModifiedUser'],
                     'Path': found['Name'],
-                    'Contents': unescape_curly_brackets(templates[0]['Value']),
+                    # 'Contents': unescape_curly_brackets(templates[0]['Value']),
+                    'Contents': templates[0]['Value'],
                     }
 
         return result
@@ -150,7 +151,7 @@ class AwsSsmTemplateProvider(TemplateProvider):
             if not found['Type'] == 'StringList':
                 raise DSOException(f"Template '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM template: path={found['Name']}")
-        response = ssm.get_parameter_history(Name=found['Name'])
+        response = get_ssm_parameter_history(found['Name'])
         parameters = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
         if include_contents:
             result = { "Revisions":
@@ -194,7 +195,7 @@ class AwsSsmTemplateProvider(TemplateProvider):
             if not found['Type'] == 'StringList':
                 raise DSOException(f"Template '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Deleting SSM template: path={found['Name']}")
-        response = ssm.delete_parameter(Name=found['Name'])
+        delete_ssm_parameter(found['Name'])
         return {
                 'Key': key, 
                 'Scope': found['Scope'],
@@ -204,6 +205,5 @@ class AwsSsmTemplateProvider(TemplateProvider):
 
 
 
-
-
-Providers.register(AwsSsmTemplateProvider())
+def register():
+    Providers.register(AwsSsmTemplateProvider())
