@@ -49,7 +49,7 @@ class ProviderManager():
         providerPackagePath = os.path.join(Configs.install_path, 'provider', provider_id)
         if not os.path.exists(providerPackagePath):
             raise DSOException(f"Providers '{provider_id}' not found.")
-        imp.load_package(provider_id, providerPackagePath)
+        imp.load_package(provider_id, providerPackagePath).register()
 
     def register(self, provider: ProviderBase):
         if not provider.id in self.__providers:
