@@ -75,7 +75,8 @@ class TemplateManager():
         application = Configs.application
         stage = Stages.normalize(stage)
         provider = Providers.TemplateProvider()
-        Logger.info(f"Start adding template: project={project}, application={application}, stage={Stages.shorten(stage)}, render_path={render_path}")
+        Logger.info(f"Start adding template '{key}': project={project}, application={application}, stage={Stages.shorten(stage)}")
+        Logger.debug(f"Template: key={key}, render_path={render_path}")
         result = provider.add(project, application, stage, key, contents)
         result['RenderTo'] = render_path
         if os.path.abspath(render_path) == os.path.abspath(os.path.join(self.default_render_path, key)):
@@ -136,7 +137,7 @@ class TemplateManager():
         Logger.info("Loading templates...")
         templates = self.list(stage, filter=filter)['Templates']
 
-        jinja_env = jinja2.Environment(undefined=jinja2.StrictUndefined)
+        jinja_env = jinja2.Environment(loader=jinja2.FileSystemLoader(Configs.working_dir), undefined=jinja2.StrictUndefined)
 
         Logger.info("Rendering templates...")
         rendered = []
